Struct rustjs::deno_core::parking_lot::lock_api::MappedRwLockReadGuard
source · pub struct MappedRwLockReadGuard<'a, R, T>{ /* private fields */ }Expand description
An RAII read lock guard returned by RwLockReadGuard::map, which can point to a
subfield of the protected data.
The main difference between MappedRwLockReadGuard and RwLockReadGuard is that the
former doesn’t support temporarily unlocking and re-locking, since that
could introduce soundness issues if the locked object is modified by another
thread.
Implementations
sourceimpl<'a, R, T> MappedRwLockReadGuard<'a, R, T>
impl<'a, R, T> MappedRwLockReadGuard<'a, R, T>
sourcepub fn map<U, F>(
s: MappedRwLockReadGuard<'a, R, T>,
f: F,
) -> MappedRwLockReadGuard<'a, R, U>
pub fn map<U, F>( s: MappedRwLockReadGuard<'a, R, T>, f: F, ) -> MappedRwLockReadGuard<'a, R, U>
Make a new MappedRwLockReadGuard for a component of the locked data.
This operation cannot fail as the MappedRwLockReadGuard passed
in already locked the data.
This is an associated function that needs to be
used as MappedRwLockReadGuard::map(...). A method would interfere with methods of
the same name on the contents of the locked data.
sourcepub fn try_map<U, F>(
s: MappedRwLockReadGuard<'a, R, T>,
f: F,
) -> Result<MappedRwLockReadGuard<'a, R, U>, MappedRwLockReadGuard<'a, R, T>>
pub fn try_map<U, F>( s: MappedRwLockReadGuard<'a, R, T>, f: F, ) -> Result<MappedRwLockReadGuard<'a, R, U>, MappedRwLockReadGuard<'a, R, T>>
Attempts to make a new MappedRwLockReadGuard for a component of the
locked data. The original guard is return if the closure returns None.
This operation cannot fail as the MappedRwLockReadGuard passed
in already locked the data.
This is an associated function that needs to be
used as MappedRwLockReadGuard::try_map(...). A method would interfere with methods of
the same name on the contents of the locked data.
sourceimpl<'a, R, T> MappedRwLockReadGuard<'a, R, T>where
R: RawRwLockFair + 'a,
T: 'a + ?Sized,
impl<'a, R, T> MappedRwLockReadGuard<'a, R, T>where
R: RawRwLockFair + 'a,
T: 'a + ?Sized,
sourcepub fn unlock_fair(s: MappedRwLockReadGuard<'a, R, T>)
pub fn unlock_fair(s: MappedRwLockReadGuard<'a, R, T>)
Unlocks the RwLock using a fair unlock protocol.
By default, RwLock is unfair and allow the current thread to re-lock
the RwLock before another has the chance to acquire the lock, even if
that thread has been blocked on the RwLock for a long time. This is
the default because it allows much higher throughput as it avoids
forcing a context switch on every RwLock unlock. This can result in one
thread acquiring a RwLock many more times than other threads.
However in some cases it can be beneficial to ensure fairness by forcing
the lock to pass on to a waiting thread if there is one. This is done by
using this method instead of dropping the MappedRwLockReadGuard normally.