Enum rustjs::deno_crypto::rand::distributions::weighted::WeightedError
source · pub enum WeightedError {
NoItem,
InvalidWeight,
AllWeightsZero,
TooMany,
}Expand description
Error type returned from WeightedIndex::new.
Variants
NoItem
The provided weight collection contains no items.
InvalidWeight
A weight is either less than zero, greater than the supported maximum, NaN, or otherwise invalid.
AllWeightsZero
All items in the provided weight collection are zero.
TooMany
Too many weights are provided (length greater than u32::MAX)