Struct rustjs::deno_fetch::reqwest::Error

source ·
pub struct Error { /* private fields */ }
The Errors that may occur when processing a Request.

Note: Errors may include the full URL used to make the Request. If the URL contains sensitive information (e.g. an API key as a query parameter), be sure to remove it (without_url)

Implementations

source

impl Error

source

pub fn url(&self) -> Option<&Url>

Returns a possible URL related to this error.

Examples
// displays last stop of a redirect loop
let response = reqwest::get("http://site.with.redirect.loop").await;
if let Err(e) = response {
    if e.is_redirect() {
        if let Some(final_stop) = e.url() {
            println!("redirect loop at {}", final_stop);
        }
    }
}
source

pub fn url_mut(&mut self) -> Option<&mut Url>

Returns a mutable reference to the URL related to this error

This is useful if you need to remove sensitive information from the URL (e.g. an API key in the query), but do not want to remove the URL entirely.

source

pub fn with_url(self, url: Url) -> Error

Add a url related to this error (overwriting any existing)

source

pub fn without_url(self) -> Error

Strip the related url from this error (if, for example, it contains sensitive information)

source

pub fn is_builder(&self) -> bool

Returns true if the error is from a type Builder.

source

pub fn is_redirect(&self) -> bool

Returns true if the error is from a RedirectPolicy.

source

pub fn is_status(&self) -> bool

Returns true if the error is from Response::error_for_status.

source

pub fn is_timeout(&self) -> bool

Returns true if the error is related to a timeout.

source

pub fn is_request(&self) -> bool

Returns true if the error is related to the request

source

pub fn is_connect(&self) -> bool

Returns true if the error is related to connect

source

pub fn is_body(&self) -> bool

Returns true if the error is related to the request or response body

source

pub fn is_decode(&self) -> bool

Returns true if the error is related to decoding the response’s body

source

pub fn status(&self) -> Option<StatusCode>

Returns the status code, if the error was generated from a response.