Enum rustjs::deno_tls::rustls::SupportedCipherSuite
source · pub enum SupportedCipherSuite {
Tls12(&'static Tls12CipherSuite),
Tls13(&'static Tls13CipherSuite),
}Expand description
A cipher suite supported by rustls.
All possible instances of this type are provided by the library in
the ALL_CIPHER_SUITES array.
Variants
Tls12(&'static Tls12CipherSuite)
A TLS 1.2 cipher suite
Tls13(&'static Tls13CipherSuite)
A TLS 1.3 cipher suite
Implementations
sourceimpl SupportedCipherSuite
impl SupportedCipherSuite
sourcepub fn hash_algorithm(&self) -> &'static Algorithm
pub fn hash_algorithm(&self) -> &'static Algorithm
Which hash function to use with this suite.
sourcepub fn suite(&self) -> CipherSuite
pub fn suite(&self) -> CipherSuite
The cipher suite’s identifier
sourcepub fn version(&self) -> &'static SupportedProtocolVersion
pub fn version(&self) -> &'static SupportedProtocolVersion
Return supported protocol version for the cipher suite.
sourcepub fn usable_for_signature_algorithm(
&self,
_sig_alg: SignatureAlgorithm,
) -> bool
pub fn usable_for_signature_algorithm( &self, _sig_alg: SignatureAlgorithm, ) -> bool
Return true if this suite is usable for a key only offering sig_alg
signatures. This resolves to true for all TLS1.3 suites.