Struct rustjs::deno_tls::rustls::Certificate
source · pub struct Certificate(pub Vec<u8>);Expand description
This type contains a single certificate by value.
The certificate must be in DER-encoded X.509 format.
A common format for storing certificates is
PEM.
PEM certificates are commonly stored in files with a .pem, .cer or .crt suffix, and look
like this:
-----BEGIN CERTIFICATE-----
<base64-encoded certificate content>
-----END CERTIFICATE-----
The rustls-pemfile crate can be used
to parse PEM files. The rcgen crate can be used to
generate certificates and private keys.
Examples
Parsing a PEM file to extract DER-encoded certificates:
use std::fs::File;
use std::io::BufReader;
use rustls::Certificate;
fn load_certificates_from_pem(path: &str) -> std::io::Result<Vec<Certificate>> {
let file = File::open(path)?;
let mut reader = BufReader::new(file);
let certs = rustls_pemfile::certs(&mut reader)?;
Ok(certs.into_iter().map(Certificate).collect())
}Tuple Fields
0: Vec<u8>Trait Implementations
sourceimpl AsRef<[u8]> for Certificate
impl AsRef<[u8]> for Certificate
sourceimpl Clone for Certificate
impl Clone for Certificate
sourcefn clone(&self) -> Certificate
fn clone(&self) -> Certificate
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Codec for Certificate
impl Codec for Certificate
sourcefn encode(&self, bytes: &mut Vec<u8>)
fn encode(&self, bytes: &mut Vec<u8>)
Function for encoding itself by appending itself to
the provided vec of bytes.
sourcefn read(r: &mut Reader<'_>) -> Result<Certificate, InvalidMessage>
fn read(r: &mut Reader<'_>) -> Result<Certificate, InvalidMessage>
Function for decoding itself from the provided reader
will return Some if the decoding was successful or
None if it was not.
sourcefn get_encoding(&self) -> Vec<u8> ⓘ
fn get_encoding(&self) -> Vec<u8> ⓘ
Convenience function for encoding the implementation
into a vec and returning it
sourcefn read_bytes(bytes: &[u8]) -> Result<Self, InvalidMessage>
fn read_bytes(bytes: &[u8]) -> Result<Self, InvalidMessage>
Function for wrapping a call to the read function in
a Reader for the slice of bytes provided
sourceimpl Debug for Certificate
impl Debug for Certificate
sourceimpl Hash for Certificate
impl Hash for Certificate
sourceimpl Ord for Certificate
impl Ord for Certificate
sourcefn cmp(&self, other: &Certificate) -> Ordering
fn cmp(&self, other: &Certificate) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for Certificate
impl PartialEq for Certificate
sourcefn eq(&self, other: &Certificate) -> bool
fn eq(&self, other: &Certificate) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for Certificate
impl PartialOrd for Certificate
sourcefn partial_cmp(&self, other: &Certificate) -> Option<Ordering>
fn partial_cmp(&self, other: &Certificate) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl TlsListElement for Certificate
impl TlsListElement for Certificate
const SIZE_LEN: ListLength = _
sourceimpl<'a> TryFrom<&'a Certificate> for ParsedCertificate<'a>
impl<'a> TryFrom<&'a Certificate> for ParsedCertificate<'a>
sourcefn try_from(
value: &'a Certificate,
) -> Result<ParsedCertificate<'a>, <ParsedCertificate<'a> as TryFrom<&'a Certificate>>::Error>
fn try_from( value: &'a Certificate, ) -> Result<ParsedCertificate<'a>, <ParsedCertificate<'a> as TryFrom<&'a Certificate>>::Error>
Performs the conversion.
impl Eq for Certificate
impl StructuralPartialEq for Certificate