Struct rustjs::deno_webstorage::rusqlite::Rows
source · pub struct Rows<'stmt> { /* private fields */ }Expand description
An handle for the resulting rows of a query.
Implementations
sourceimpl<'stmt> Rows<'stmt>
impl<'stmt> Rows<'stmt>
sourcepub fn next(&mut self) -> Result<Option<&Row<'stmt>>, Error>
pub fn next(&mut self) -> Result<Option<&Row<'stmt>>, Error>
Attempt to get the next row from the query. Returns Ok(Some(Row)) if
there is another row, Err(...) if there was an error
getting the next row, and Ok(None) if all rows have been retrieved.
Note
This interface is not compatible with Rust’s Iterator trait, because
the lifetime of the returned row is tied to the lifetime of self.
This is a fallible “streaming iterator”. For a more natural interface,
consider using query_map or
query_and_then instead, which
return types that implement Iterator.
sourcepub fn map<F, B>(self, f: F) -> Map<'stmt, F>
pub fn map<F, B>(self, f: F) -> Map<'stmt, F>
Map over this Rows, converting it to a Map, which
implements FallibleIterator.
use fallible_iterator::FallibleIterator;
fn query(stmt: &mut Statement) -> Result<Vec<i64>> {
let rows = stmt.query([])?;
rows.map(|r| r.get(0)).collect()
}sourcepub fn mapped<F, B>(self, f: F) -> MappedRows<'stmt, F> ⓘ
pub fn mapped<F, B>(self, f: F) -> MappedRows<'stmt, F> ⓘ
Map over this Rows, converting it to a MappedRows, which
implements Iterator.
sourcepub fn and_then<F, T, E>(self, f: F) -> AndThenRows<'stmt, F> ⓘ
pub fn and_then<F, T, E>(self, f: F) -> AndThenRows<'stmt, F> ⓘ
Map over this Rows with a fallible function, converting it to a
AndThenRows, which implements Iterator (instead of
FallibleStreamingIterator).